summaryrefslogtreecommitdiff
path: root/sys/dev/isa
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>2002-06-03 20:01:38 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>2002-06-03 20:01:38 +0000
commit463cec6714bb295c4619fc3b722bd31baa22e4cf (patch)
tree3cfa005cb894f81142b1fab999d77843ce83e80b /sys/dev/isa
parentc0c3e2c19ba15a8d0c650139773656d2e85b2122 (diff)
spell transceiver correctly
Diffstat (limited to 'sys/dev/isa')
-rw-r--r--sys/dev/isa/if_ed.c10
-rw-r--r--sys/dev/isa/if_edreg.h6
-rw-r--r--sys/dev/isa/if_wereg.h6
3 files changed, 11 insertions, 11 deletions
diff --git a/sys/dev/isa/if_edreg.h b/sys/dev/isa/if_edreg.h
index 08a2f58cd28..603a5f8eca2 100644
--- a/sys/dev/isa/if_edreg.h
+++ b/sys/dev/isa/if_edreg.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_edreg.h,v 1.5 2001/01/25 03:50:50 todd Exp $ */
+/* $OpenBSD: if_edreg.h,v 1.6 2002/06/03 20:01:37 deraadt Exp $ */
/* $NetBSD: if_edreg.h,v 1.15 1996/01/10 16:49:22 chuck Exp $ */
/*
@@ -22,9 +22,9 @@
* Compile-time config flags
*/
/*
- * This sets the default for enabling/disablng the tranceiver.
+ * This sets the default for enabling/disablng the transceiver.
*/
-#define ED_FLAGS_DISABLE_TRANCEIVER 0x0001
+#define ED_FLAGS_DISABLE_TRANSCEIVER 0x0001
/*
* This forces the board to be used in 8/16-bit mode even if it autoconfigs
diff --git a/sys/dev/isa/if_wereg.h b/sys/dev/isa/if_wereg.h
index 4b5fbe99f99..e5b64024821 100644
--- a/sys/dev/isa/if_wereg.h
+++ b/sys/dev/isa/if_wereg.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_wereg.h,v 1.1 1998/09/22 06:33:19 fgsch Exp $ */
+/* $OpenBSD: if_wereg.h,v 1.2 2002/06/03 20:01:37 deraadt Exp $ */
/* $NetBSD: if_wereg.h,v 1.1 1997/11/03 21:22:50 thorpej Exp $ */
/*
@@ -15,9 +15,9 @@
* Compile-time config flags
*/
/*
- * This sets the default for enabling/disablng the tranceiver.
+ * This sets the default for enabling/disablng the transceiver.
*/
-#define WE_FLAGS_DISABLE_TRANCEIVER 0x0001
+#define WE_FLAGS_DISABLE_TRANSCEIVER 0x0001
/*
* This forces the board to be used in 8/16-bit mode even if it autoconfigs
diff --git a/sys/dev/isa/if_ed.c b/sys/dev/isa/if_ed.c
index 34d68a82a67..d037d884724 100644
--- a/sys/dev/isa/if_ed.c
+++ b/sys/dev/isa/if_ed.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: if_ed.c,v 1.49 2002/03/14 01:26:56 millert Exp $ */
+/* $OpenBSD: if_ed.c,v 1.50 2002/06/03 20:01:37 deraadt Exp $ */
/* $NetBSD: if_ed.c,v 1.105 1996/10/21 22:40:45 thorpej Exp $ */
/*
@@ -1197,7 +1197,7 @@ ed_find_3Com(sc, cf, ia)
/*
* Unmap PROM - select NIC registers. The proper setting of the
* tranceiver is set in edinit so that the attach code is given a
* chance to set the default based on a compile-time config option.
*/
bus_space_write_1(iot, ioh, asicbase + ED_3COM_CR, ED_3COM_CR_XSEL);
@@ -1656,12 +1656,12 @@ edattach(parent, self, aux)
IFQ_SET_READY(&ifp->if_snd);
/*
* Set default state for LINK0 flag (used to disable the tranceiver
* for AUI operation), based on compile-time config option.
*/
switch (sc->vendor) {
case ED_VENDOR_3COM:
- if (cf->cf_flags & ED_FLAGS_DISABLE_TRANCEIVER)
+ if (cf->cf_flags & ED_FLAGS_DISABLE_TRANSCEIVER)
ifp->if_flags |= IFF_LINK0;
break;
case ED_VENDOR_WD_SMC:
@@ -1883,7 +1883,7 @@ edinit(sc)
NIC_PUT(iot, ioh, nicbase, ED_P0_TCR, 0);
/*
* If this is a 3Com board, the tranceiver must be software enabled
* (there is no settable hardware default).
*/
switch (sc->vendor) {
@@ -1197,7 +1197,7 @@ ed_find_3Com(sc, cf, ia)
/*
* Unmap PROM - select NIC registers. The proper setting of the
- * tranceiver is set in edinit so that the attach code is given a
+ * transceiver is set in edinit so that the attach code is given a
* chance to set the default based on a compile-time config option.
*/
@@ -1656,12 +1656,12 @@ edattach(parent, self, aux)
IFQ_SET_READY(&ifp->if_snd);
/*
- * Set default state for LINK0 flag (used to disable the tranceiver
+ * Set default state for LINK0 flag (used to disable the transceiver
* for AUI operation), based on compile-time config option.
*/
@@ -1883,7 +1883,7 @@ edinit(sc)
NIC_PUT(iot, ioh, nicbase, ED_P0_TCR, 0);
/*
- * If this is a 3Com board, the tranceiver must be software enabled
+ * If this is a 3Com board, the transceiver must be software enabled
* (there is no settable hardware default).
*/